@@ -1,6 +1,6 @@
-<?PHP // $Id: mod.php,v 1.55.4.1 2004/06/03 13:07:44 moodler Exp $
+<?PHP // $Id: mod.php,v 1.60.2.3 2004/10/09 17:02:26 stronk7 Exp $
 
-//  Moves, adds, updates or deletes modules in a course
+//  Moves, adds, updates, duplicates or deletes modules in a course
 
     require("../config.php");
     require("lib.php");
@@ -27,6 +27,14 @@
 
     if (isset($_POST["course"])) {    // add or update form submitted
 
+        //It caller is correct, $SESSION->sesskey must exist and coincide
+        if (empty($SESSION->sesskey) or !confirm_sesskey($SESSION->sesskey)) {
+            error(get_string('confirmsesskeybad', 'error'));
+        }
+
+        //Unset this, check done
+        unset($SESSION->sesskey);
+
         if (!$course = get_record("course", "id", $mod->course)) {
             error("This course doesn't exist");
         }
@@ -35,7 +43,9 @@
             error("You can't modify this course!");
         }
 
+        $mod->modulename = clean_filename($mod->modulename);  // For safety
         $modlib = "$CFG->dirroot/mod/$mod->modulename/lib.php";
+
         if (file_exists($modlib)) {
             include_once($modlib);
         } else {
@@ -48,6 +58,11 @@
 
         switch ($mod->mode) {
             case "update":
+
+                if (trim($mod->name) == '') {
+                    unset($mod->name);
+                }
+
                 $return = $updateinstancefunction($mod);
                 if (!$return) {
                     if (file_exists($moderr)) {
@@ -60,6 +75,9 @@
                 if (is_string($return)) {
                     error($return, "view.php?id=$course->id");
                 }
+
+                $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
+
                 add_to_log($course->id, "course", "update mod", 
                            "../mod/$mod->modulename/view.php?id=$mod->coursemodule", 
                            "$mod->modulename $mod->instance"); 
@@ -69,6 +87,11 @@
                 break;
 
             case "add":
+
+                if (trim($mod->name) == '') {
+                    $mod->name = get_string("modulename", $mod->modulename);
+                }
+
                 $return = $addinstancefunction($mod);
                 if (!$return) {
                     if (file_exists($moderr)) {
@@ -104,6 +127,9 @@
                 if (! set_field("course_modules", "section", $sectionid, "id", $mod->coursemodule)) {
                     error("Could not update the course module with the correct section");
                 }   
+
+                $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
+                
                 add_to_log($course->id, "course", "add mod", 
                            "../mod/$mod->modulename/view.php?id=$mod->coursemodule", 
                            "$mod->modulename $mod->instance"); 
@@ -111,6 +137,7 @@
                            "view.php?id=$mod->coursemodule", 
                            "$mod->instance", $mod->coursemodule); 
                 break;
+                
             case "delete":
                 if (! $deleteinstancefunction($mod->instance)) {
                     notify("Could not delete the $mod->modulename (instance)");
@@ -121,6 +148,9 @@
                 if (! delete_mod_from_section($mod->coursemodule, "$mod->section")) {
                     notify("Could not delete the $mod->modulename from that section");
                 }
+
+                unset($SESSION->returnpage);
+
                 add_to_log($course->id, "course", "delete mod", 
                            "view.php?id=$mod->course", 
                            "$mod->modulename $mod->instance", $mod->coursemodule); 
@@ -143,7 +173,7 @@
     }
 
 
-    if (isset($_GET['move'])) {  
+    if (isset($_GET['move']) and confirm_sesskey()) {  
 
         require_variable($id);   
 
@@ -167,7 +197,7 @@
         }
         exit;
 
-    } else if (isset($_GET['movetosection']) or isset($_GET['moveto'])) {  
+    } else if ((isset($_GET['movetosection']) or isset($_GET['moveto'])) and confirm_sesskey()) {  
         
         if (! $cm = get_record("course_modules", "id", $USER->activitycopy)) {
             error("The copied course module doesn't exist!");
@@ -211,7 +241,7 @@
             redirect("view.php?id=$section->course");
         }
 
-    } else if (isset($_GET['indent'])) {  
+    } else if (isset($_GET['indent']) and confirm_sesskey()) {  
 
         require_variable($id);   
 
@@ -237,7 +267,7 @@
         }
         exit;
 
-    } else if (isset($_GET['hide'])) {
+    } else if (isset($_GET['hide']) and confirm_sesskey()) {
 
         if (! $cm = get_record("course_modules", "id", $_GET['hide'])) {
             error("This course module doesn't exist");
@@ -259,7 +289,7 @@
         }
         exit;
 
-    } else if (isset($_GET['show'])) {
+    } else if (isset($_GET['show']) and confirm_sesskey()) {
 
         if (! $cm = get_record("course_modules", "id", $_GET['show'])) {
             error("This course module doesn't exist");
@@ -291,7 +321,7 @@
         }
         exit;
 
-    } else if (isset($_GET['groupmode'])) {
+    } else if (isset($_GET['groupmode']) and confirm_sesskey()) {
 
         if (! $cm = get_record("course_modules", "id", $_GET['id'])) {
             error("This course module doesn't exist");
@@ -313,7 +343,7 @@
         }
         exit;
 
-    } else if (isset($_GET['copy'])) { // value = course module
+    } else if (isset($_GET['copy']) and confirm_sesskey()) { // value = course module
 
         if (! $cm = get_record("course_modules", "id", $_GET['copy'])) {
             error("This course module doesn't exist");
@@ -341,7 +371,7 @@
 
         redirect("view.php?id=$cm->course");
 
-    } else if (isset($_GET['cancelcopy'])) { // value = course module
+    } else if (isset($_GET['cancelcopy']) and confirm_sesskey()) { // value = course module
 
         $courseid = $USER->activitycopycourse;
 
@@ -351,7 +381,7 @@
 
         redirect("view.php?id=$courseid");
 
-    } else if (isset($_GET['delete'])) {   // value = course module
+    } else if (isset($_GET['delete']) and confirm_sesskey()) {   // value = course module
 
         if (! $cm = get_record("course_modules", "id", $_GET['delete'])) {
             error("This course module doesn't exist");
@@ -390,13 +420,13 @@
         $form->modulename   = $module->name;
         $form->fullmodulename  = $fullmodulename;
         $form->instancename = $instance->name;
+        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
 
         $strdeletecheck = get_string("deletecheck", "", "$form->fullmodulename");
         $strdeletecheckfull = get_string("deletecheckfull", "", "$form->fullmodulename '$form->instancename'");
 
-        print_header("$course->shortname: $strdeletecheck", "$course->fullname",
-                     "<A HREF=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</A> -> 
-                      $strdeletecheck");
+        print_header_simple("$strdeletecheck", "$",
+                     "$strdeletecheck");
 
         print_simple_box_start("center", "60%", "#FFAAAA", 20, "noticebox");
         print_heading($strdeletecheckfull);
@@ -407,7 +437,7 @@
         exit;
 
 
-    } else if (isset($_GET['update'])) {   // value = course module
+    } else if (isset($_GET['update']) and confirm_sesskey()) {   // value = course module
 
         if (! $cm = get_record("course_modules", "id", $_GET['update'])) {
             error("This course module doesn't exist");
@@ -444,6 +474,7 @@
         $form->modulename   = $module->name;
         $form->instance     = $cm->instance;
         $form->mode         = "update";
+        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
 
         $sectionname    = get_string("name$course->format");
         $fullmodulename = strtolower(get_string("modulename", $module->name));
@@ -456,8 +487,60 @@
             $pageheading = get_string("updatinga", "moodle", $fullmodulename);
         }
 
+    } else if (isset($_GET['duplicate']) and confirm_sesskey()) {   // value = course module
+
+        if (! $cm = get_record("course_modules", "id", $_GET['duplicate'])) {
+            error("This course module doesn't exist");
+        }
+
+        if (! $course = get_record("course", "id", $cm->course)) {
+            error("This course doesn't exist");
+        }
+
+        if (!isteacheredit($course->id)) {
+            error("You can't modify this course!");
+        }
+
+        if (! $module = get_record("modules", "id", $cm->module)) {
+            error("This module doesn't exist");
+        }
+
+        if (! $form = get_record($module->name, "id", $cm->instance)) {
+            error("The required instance of this module doesn't exist");
+        }
         
-    } else if (isset($_GET['add'])) {
+        if (! $cw = get_record("course_sections", "id", $cm->section)) {
+            error("This course section doesn't exist");
+        }
+
+        if (isset($return)) {  
+            $SESSION->returnpage = "$CFG->wwwroot/mod/$module->name/view.php?id=$cm->id";
+        }
+        
+        $section = get_field('course_sections', 'section', 'id', $cm->section);
+
+        $form->coursemodule = $cm->id;
+        $form->section      = $section;     // The section ID
+        $form->course       = $course->id;
+        $form->module       = $module->id;
+        $form->modulename   = $module->name;
+        $form->instance     = $cm->instance;
+        $form->mode         = "add";
+        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
+
+        $sectionname    = get_string("name$course->format");
+        $fullmodulename = strtolower(get_string("modulename", $module->name));
+
+        if ($form->section) {
+            $heading->what = $fullmodulename;
+            $heading->in   = "$sectionname $cw->section";
+            $pageheading = get_string("duplicatingain", "moodle", $heading);
+        } else {
+            $pageheading = get_string("duplicatinga", "moodle", $fullmodulename);
+        }
+
+        
+    } else if (isset($_GET['add']) and confirm_sesskey()) {
 
         if (empty($_GET['add'])) {
             redirect($_SERVER["HTTP_REFERER"]);
@@ -482,6 +565,10 @@
         $form->instance   = "";
         $form->coursemodule = "";
         $form->mode       = "add";
+        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
+        if (isset($_GET['type'])) {
+            $form->type = $_GET['type'];
+        }
 
         $sectionname    = get_string("name$course->format");
         $fullmodulename = get_string("modulename", $module->name);
@@ -529,6 +616,7 @@
 
         if ($usehtmleditor = can_use_html_editor()) {
             $defaultformat = FORMAT_HTML;
+            $editorfields = '';
         } else {
             $defaultformat = FORMAT_MOODLE;
         }
@@ -541,7 +629,7 @@
         print_simple_box_end();
 
         if ($usehtmleditor and empty($nohtmleditorneeded)) { 
-            use_html_editor();
+            use_html_editor($editorfields);
         }
 
     } else {
