@@ -1,21 +1,31 @@
-<?PHP // $Id: choice.php,v 1.11 2004/02/04 13:40:20 moodler Exp $ 
+<?php // $Id$ 
       // choice.php - created with Moodle 1.2 development (2003111400)
 
 
+$string['allowupdate'] = 'Allow choice to be updated';
 $string['answered'] = 'Answered';
 $string['choice'] = 'Choice $a';
+$string['choiceclose'] = 'Until';
 $string['choicename'] = 'Choice name';
+$string['choiceopen'] = 'Open';
 $string['choicetext'] = 'Choice text';
+$string['havetologin'] = 'You have to log in before you can submit your choice';
 $string['modulename'] = 'Choice';
 $string['modulenameplural'] = 'Choices';
 $string['mustchooseone'] = 'You must choose an answer before saving.  Nothing was saved.';
 $string['notanswered'] = 'Not answered yet';
+$string['notopenyet'] = 'Sorry, this activity is not available until $a';
 $string['publish'] = 'Publish results';
+$string['publishafteranswer'] = 'Show results to a student after they answer';
+$string['publishafterclose'] = 'Show results to students only after the choice is closed';
+$string['publishalways'] = 'Always show results to students';
 $string['publishanonymous'] = 'Publish anonymous results, do not show student names';
 $string['publishnames'] = 'Publish full results, showing names and their choices';
 $string['publishnot'] = 'Do not publish results to students';
+$string['privacy'] = 'Privacy of results';
 $string['responses'] = 'Responses';
 $string['responsesto'] = 'Responses to $a';
+$string['timerestrict'] = 'Restrict answering to this time period';
 $string['savemychoice'] = 'Save my choice';
 $string['showunanswered'] = 'Show column for unanswered';
 $string['viewallresponses'] = 'View $a responses';
