@@ -1,4 +1,4 @@
-<?PHP // $Id: moodle.php,v 1.3 2003/11/30 14:15:39 moodler Exp $ 
+<?PHP // $Id$ 
       // moodle.php - created with Moodle 1.1.1 (2003091111)
 
 
@@ -223,9 +223,9 @@ $string['emailformat'] = "Email formtuma";
 $string['emailmustbereal'] = "Megj.: az email-cmnek valdinak kell lennie";
 $string['emailpasswordconfirmationsubject'] = "\$a: megvltozott jelsz visszaigazolsa";
 $string['enrolmentkey'] = "Beiratkoz kd";
-$string['enrolmentkeyfrom'] = "Ez a kurzus egy 'beiratkoz kdot' ignyel - amely egy egyszeri<BR>
+$string['enrolmentkeyfrom'] = "Ez a kurzus egy 'beiratkoz kdot' ignyel - amely egy egyszeri<br />
 jelsz, mely \$a -tl kaphat meg";
-$string['enrolmentkeyhint'] = "Ez a beiratkoz kdot nem megfelel, prblja jra<BR>
+$string['enrolmentkeyhint'] = "Ez a beiratkoz kdot nem megfelel, prblja jra<br />
 (Egy tipp - '\$a' -val kezddik)";
 $string['entercourse'] = "Kattintssal lpjen be a tanfolyamra";
 $string['enteremailaddress'] = "rja be az email-cmt jelszavnak trlshez, s j jelszavnak emailen trtn elkldshez.";
