@@ -1,4 +1,4 @@
-<?PHP  //$Id: mysql.php,v 1.92 2004/05/05 07:07:53 gustav_delius Exp $
+<?PHP  //$Id: mysql.php,v 1.105.2.10 2004/11/24 02:20:43 martinlanghoff Exp $
 //
 // This file keeps track of upgrades to Moodle.
 //
@@ -429,11 +429,7 @@ function main_upgrade($oldversion=0) {
 
     if ($oldversion < 2003080700) {
         notify("Cleaning up categories and course ordering...");
-        if ($categories = get_categories()) {
-            foreach ($categories as $category) {
-                fix_course_sortorder($category->id);
-            }
-        }
+        fix_course_sortorder();
     }
 
     if ($oldversion < 2003081001) {
@@ -765,8 +761,206 @@ function main_upgrade($oldversion=0) {
         }
     }
 
-    return $result;
+    if ($oldversion < 2004052800) {     /// First version tagged "1.4 development", version.php 1.227
+        set_config('siteblocksadded', true);   /// This will be used later by the block upgrade
+    }
 
+    if ($oldversion < 2004053000) {     /// set defaults for site course
+        $site = get_site();
+        set_field('course', 'numsections', 0, 'id', $site->id);
+        set_field('course', 'groupmodeforce', 1, 'id', $site->id);
+        set_field('course', 'teacher', get_string('administrator'), 'id', $site->id);
+        set_field('course', 'teachers', get_string('administrators'), 'id', $site->id);
+        set_field('course', 'student', get_string('user'), 'id', $site->id);
+        set_field('course', 'students', get_string('users'), 'id', $site->id);
+    }
+
+    if ($oldversion < 2004060100) {
+        set_config('digestmailtime', 0);
+        table_column('user', "", 'maildigest', 'tinyint', '1', '', '0', 'not null', 'mailformat');
+    }
+
+    if ($oldversion < 2004062400) {
+        table_column('user_teachers', "", 'timeend', 'int', '10', 'unsigned', '0', 'not null', 'editall');
+        table_column('user_teachers', "", 'timestart', 'int', '10', 'unsigned', '0', 'not null', 'editall');
+    }
+
+    if ($oldversion < 2004062401) {
+        table_column('course', '', 'idnumber', 'varchar', '100', '', '', 'not null', 'shortname');
+        execute_sql('UPDATE '.$CFG->prefix.'course SET idnumber = shortname');   // By default
+    }
+
+    if ($oldversion < 2004062600) {
+        table_column('course', '', 'cost', 'varchar', '10', '', '', 'not null', 'lang');
+    }
+
+    if ($oldversion < 2004072900) {
+        table_column('course', '', 'enrolperiod', 'int', '10', 'unsigned', '0', 'not null', 'startdate');
+    }
+
+    if ($oldversion < 2004072901) {  // Fixing error in schema
+        if ($record = get_record('log_display', 'module', 'course', 'action', 'update')) {
+            delete_records('log_display', 'module', 'course', 'action', 'update');
+            insert_record('log_display', $record, false, 'module');
+        }
+    }
+
+    if ($oldversion < 2004081200) {  // Fixing version errors in some blocks
+        set_field('blocks', 'version', 2004081200, 'name', 'admin');
+        set_field('blocks', 'version', 2004081200, 'name', 'calendar_month');
+        set_field('blocks', 'version', 2004081200, 'name', 'course_list');
+    }
+
+    if ($oldversion < 2004081500) {  // Adding new "auth" field to user table to allow more flexibility
+        table_column('user', '', 'auth', 'varchar', '20', '', 'manual', 'not null', 'id');
+
+        execute_sql("UPDATE {$CFG->prefix}user SET auth = 'manual'");  // Set everyone to 'manual' to be sure
+
+        if ($admins = get_admins()) {   // Set all the NON-admins to whatever the current auth module is
+            $adminlist = array();
+            foreach ($admins as $user) {
+                $adminlist[] = $user->id; 
+            }
+            $adminlist = implode(',', $adminlist);
+            execute_sql("UPDATE {$CFG->prefix}user SET auth = '$CFG->auth' WHERE id NOT IN ($adminlist)");
+        }
+    }
+    
+    if ($oldversion < 2004082200) { // Making admins teachers on site course
+        $site = get_site();
+        $admins = get_admins();
+        foreach ($admins as $admin) {
+            add_teacher($admin->id, $site->id);
+        }
+    }
+
+    if ($oldversion < 2004082900) {  // Make sure guest is "manual" too.
+        set_field('user', 'auth', 'manual', 'username', 'guest');
+    }
+
+    if ($oldversion < 2004083127) {  // Update any users/courses using wrongly-named lang pack
+        execute_sql("UPDATE {$CFG->prefix}user SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
+        execute_sql("UPDATE {$CFG->prefix}course SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
+    }
+
+    if ($oldversion < 2004083128) { // add indexes.
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user` ADD INDEX user_idnumber (idnumber) ");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user` ADD INDEX user_auth (auth) ");
+    }
+
+    if ($oldversion < 2004083128) { // add indexes.
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX idnumber (idnumber) ");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX shortname (shortname) ");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_students` ADD INDEX userid (userid) ");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_teachers` ADD INDEX userid (userid) ");
+    }
+
+    if ($oldversion < 2004083128) {// add an index to event for timestart and timeduration
+        modify_database('','ALTER TABLE prefix_event ADD INDEX timestart (timestart);');
+        modify_database('','ALTER TABLE prefix_event ADD INDEX timeduration (timeduration);');
+    }
+
+    if ($oldversion < 2004083128) { //add indexes on modules and course_modules
+        modify_database('','ALTER TABLE prefix_course_modules add key visible(visible);');
+        modify_database('','ALTER TABLE prefix_course_modules add key course(course);');
+        modify_database('','ALTER TABLE prefix_course_modules add key module(module);');
+        modify_database('','ALTER TABLE prefix_course_modules add key instance (instance);');
+        modify_database('','ALTER TABLE prefix_course_modules add key deleted (deleted);');
+        modify_database('','ALTER TABLE prefix_modules add key name(name);');
+    }
+
+
+    if ($oldversion < 2004083128) { // add an index on the groups_members table
+        modify_database('','ALTER TABLE prefix_groups_members ADD INDEX userid (userid);');
+    }
+
+    if ($oldversion < 2004083128) { // add an index on user students timeaccess (used for sorting)
+        modify_database('','ALTER TABLE prefix_user_students ADD INDEX timeaccess (timeaccess);');
+    }
+
+    if ($oldversion < 2004083128) { 
+        modify_database('','ALTER TABLE prefix_scale ADD INDEX courseid (courseid);');
+        modify_database('','ALTER TABLE prefix_user_admins ADD INDEX userid (userid);');
+        modify_database('','ALTER TABLE prefix_user_coursecreators ADD INDEX userid (userid);');
+    }
+
+    if ($oldversion < 2004083128) { // replace index on course
+        fix_course_sortorder(0,0,1);
+        modify_database('', "ALTER TABLE `prefix_course` DROP KEY category");
+        modify_database('', "ALTER TABLE `prefix_course` ADD UNIQUE KEY category_sortorder(category,sortorder)"); 
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_deleted_idx  (deleted)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_confirmed_idx (confirmed)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_firstname_idx (firstname)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_lastname_idx (lastname)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_city_idx (city)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_country_idx (country)");
+        modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_lastaccess_idx (lastaccess)");
+    }
+    
+    if ($oldversion < 2004083128) { // one more index for email (for sorting)
+        modify_database('','ALTER TABLE `prefix_user` ADD INDEX prefix_user_email_idx (email);');
+    }
+
+    if ($oldversion < 2004083129) { // Undoing some module version mess from recent upgrade
+        if (get_field('modules', 'version', 'name', 'assignment') == '2004111200') {
+            set_field('modules', 'version', 2004060401, 'name', 'assignment');
+        }
+        if (get_field('modules', 'version', 'name', 'attendance') == '2004111200') {
+            set_field('modules', 'version', 2004060401, 'name', 'attendance');
+        }
+        if (get_field('modules', 'version', 'name', 'chat') == '2004121100') {
+            set_field('modules', 'version', 2004060401, 'name', 'chat');
+        }
+        if (get_field('modules', 'version', 'name', 'choice') == '2004111200') {
+            set_field('modules', 'version', 2004070103, 'name', 'choice');
+        }
+        if (get_field('modules', 'version', 'name', 'dialogue') == '2004111000') {
+            set_field('modules', 'version', 2004060401, 'name', 'dialogue');
+        }
+        if (get_field('modules', 'version', 'name', 'exercise') == '2004111200') {
+            set_field('modules', 'version', 2004062301, 'name', 'exercise');
+        }
+        if (get_field('modules', 'version', 'name', 'forum') == '2004111200') {
+            set_field('modules', 'version', 2004081801, 'name', 'forum');
+        }
+        if (get_field('modules', 'version', 'name', 'glossary') == '2004111200') {
+            set_field('modules', 'version', 2004080932, 'name', 'glossary');
+        }
+    }
+
+    
+    if ($oldversion < 2004083130) {
+        /// Delete duplicate enrolments 
+        /// and then tell the database course,userid is a unique combination
+        if ($users = get_records_select("user_students", "userid > 0 GROUP BY course, userid ".
+                                        "HAVING count(*) > 1", "", "max(id) as id, userid, course ,count(*)")) {
+            foreach ($users as $user) {
+                delete_records_select("user_students", "userid = '$user->userid' ".
+                                     "AND course = '$user->course' AND id <> '$user->id'");
+            }
+        }
+        flush();
+        
+        modify_database('','ALTER TABLE prefix_user_students DROP INDEX courseuserid;');
+        modify_database('','ALTER TABLE prefix_user_students ADD UNIQUE INDEX courseuserid(course,userid);');        
+
+        /// Delete duplicate teacher enrolments 
+        /// and then tell the database course,userid is a unique combination
+        if ($users = get_records_select("user_teachers", "userid > 0 GROUP BY course, userid ".
+                                        "HAVING count(*) > 1", "", "max(id) as id, userid, course ,count(*)")) {
+            foreach ($users as $user) {
+                delete_records_select("user_teachers", "userid = '$user->userid' ".
+                                     "AND course = '$user->course' AND id <> '$user->id'");
+            }
+        }
+        flush();
+        
+        modify_database('','ALTER TABLE prefix_user_teachers DROP INDEX courseuserid;');
+        modify_database('','ALTER TABLE prefix_user_teachers ADD UNIQUE INDEX courseuserid(course,userid);');        
+    } 
+       
+    return $result;
+    
 }
 
 ?>
