@@ -1,9 +1,11 @@
-<?PHP // $Id: index.php,v 1.41 2004/04/03 04:55:35 moodler Exp $
+<?PHP // $Id: index.php,v 1.45.2.4 2004/12/19 14:10:03 moodler Exp $
 
     require_once("../config.php");
+    optional_variable($loginguest, false); // determines whether visitors are logged in as guest automatically
 
     // Check if the guest user exists.  If not, create one.
     if (! record_exists("user", "username", "guest")) {
+        $guest->auth        = "manual"; 
         $guest->username    = "guest"; 
         $guest->password    = md5("guest");
         $guest->firstname   = addslashes(get_string("guestuser"));
@@ -20,7 +22,7 @@
     }
 
     $frm = false;
-    if (!empty($SESSION->wantsurl) and strstr($SESSION->wantsurl,"username=guest")) {
+    if ((!empty($SESSION->wantsurl) and strstr($SESSION->wantsurl,"username=guest")) or $loginguest) {
         /// Log in as guest automatically (idea from Zbigniew Fiedorowicz)
         $frm->username = "guest";
         $frm->password = "guest";
@@ -30,7 +32,13 @@
 
     if ($frm) {
         $frm->username = trim(moodle_strtolower($frm->username));
-        $user = authenticate_user_login($frm->username, $frm->password);
+
+        if (($frm->username == 'guest') and empty($CFG->guestloginbutton)) {
+            $user = false;    /// Can't log in as guest if guest button is disabled
+            $frm = false;
+        } else {
+            $user = authenticate_user_login($frm->username, $frm->password);
+        }
         update_login_count();
 
         if ($user) {
@@ -47,7 +55,8 @@
                 $USER->description = true;       // No need to cart all of it around
             }
             $USER->loggedin = true;
-            $USER->site = $CFG->wwwroot;   // for added security
+            $USER->site     = $CFG->wwwroot;     // for added security, store the site in the session
+            $USER->sesskey  = random_string(10); // for added security, used to check script parameters
             
             if ($USER->username == "guest") {
                 $USER->lang       = $CFG->lang;               // Guest language always same as site
@@ -69,6 +78,11 @@
 
             unset($SESSION->wantsurl);
             unset($SESSION->lang);
+            $SESSION->justloggedin = true;
+
+            add_to_log(SITEID, "user", "login", "view.php?id=$user->id&course=".SITEID, $user->id, 0, $user->id);
+
+            reset_login_count();
 
             if (user_not_fully_set_up($USER)) {
                 $site = get_site();
@@ -80,8 +94,6 @@
             } else {
                 redirect("$CFG->wwwroot/");      /// Go to the standard home page
             }
-    
-            reset_login_count();
 
             die;
     
@@ -96,7 +108,7 @@
     }
 
     if (empty($SESSION->wantsurl)) {
-        $SESSION->wantsurl = $_SERVER["HTTP_REFERER"];
+        $SESSION->wantsurl = array_key_exists('HTTP_REFERER',$_SERVER) ? $_SERVER["HTTP_REFERER"] : $CFG->wwwroot; 
     }
     
     if (empty($frm->username)) {
@@ -125,7 +137,12 @@
     } else {
         $currlang = current_language();
         $langs    = get_list_of_languages();
-        $langmenu = popup_form ("$CFG->wwwroot/login/index.php?lang=", $langs, "chooselang", $currlang, "", "", "", true);
+        if (empty($CFG->loginhttps)) {
+            $wwwroot = $CFG->wwwroot;
+        } else {
+            $wwwroot = str_replace('http','https',$CFG->wwwroot);
+        }
+        $langmenu = popup_form ("$wwwroot/login/index.php?lang=", $langs, "chooselang", $currlang, "", "", "", true);
     }
 
     $loginsite = get_string("loginsite");
