@@ -1,4 +1,4 @@
-<?PHP  // $Id: lib.php,v 1.64 2004/05/17 16:24:19 moodler Exp $
+<?PHP  // $Id: lib.php,v 1.68.2.2 2004/11/07 15:24:49 moodler Exp $
 
 require_once("$CFG->dirroot/files/mimetypes.php");
 
@@ -181,7 +181,7 @@ function assignment_user_complete($course, $user, $mod, $assignment) {
         if (empty($submission->timemarked)) {
             print_string("notgradedyet", "assignment");
         } else {
-            assignment_print_feedback($course, $submission);
+            assignment_print_feedback($course, $submission, $assignment);
         }
 
         print_simple_box_end();
@@ -198,9 +198,23 @@ function assignment_cron () {
 
     global $CFG, $USER;
 
-    $cutofftime = time() - $CFG->maxeditingtime;
+    /// Notices older than 1 day will not be mailed.  This is to avoid the problem where
+    /// cron has not been running for a long time, and then suddenly people are flooded
+    /// with mail from the past few weeks or months
+
+    $timenow   = time();
+    $endtime   = $timenow - $CFG->maxeditingtime;
+    $starttime = $endtime - 24 * 3600;   /// One day earlier
+
+    if ($submissions = assignment_get_unmailed_submissions($starttime, $endtime)) {
+
+        foreach ($submissions as $key => $submission) {
+            if (! set_field("assignment_submissions", "mailed", "1", "id", "$submission->id")) {
+                echo "Could not update the mailed field for id $submission->id.  Not mailed.\n";
+                unset($submissions[$key]);
+            }
+        }
 
-    if ($submissions = assignment_get_unmailed_submissions($cutofftime)) {
         $timenow = time();
 
         foreach ($submissions as $submission) {
@@ -267,9 +281,6 @@ function assignment_cron () {
             if (! email_to_user($user, $teacher, $postsubject, $posttext, $posthtml)) {
                 echo "Error: assignment cron: Could not send out mail for id $submission->id to user $user->id ($user->email)\n";
             }
-            if (! set_field("assignment_submissions", "mailed", "1", "id", "$submission->id")) {
-                echo "Could not update the mailed field for id $submission->id\n";
-            }
         }
     }
 
@@ -411,21 +422,25 @@ function assignment_count_real_submissions($assignment, $groupid=0) {
     global $CFG;
 
     if ($groupid) {     /// How many in a particular group?
-        return count_records_sql("SELECT COUNT(*) 
+        return count_records_sql("SELECT COUNT(DISTINCT g.userid, g.groupid)
                                      FROM {$CFG->prefix}assignment_submissions a,
                                           {$CFG->prefix}groups_members g
                                     WHERE a.assignment = $assignment->id 
                                       AND a.timemodified > 0
                                       AND g.groupid = '$groupid' 
                                       AND a.userid = g.userid ");
-    } else {                                  
+    } else {
+        $select = "s.course = '$assignment->course' AND";
+        $site = get_site();
+        if ($assignment->course == $site->id) {
+            $select = '';
+        }     
         return count_records_sql("SELECT COUNT(*)
                                   FROM {$CFG->prefix}assignment_submissions a, 
                                        {$CFG->prefix}user_students s
                                  WHERE a.assignment = '$assignment->id' 
                                    AND a.timemodified > 0
-                                   AND s.course = '$assignment->course'
-                                   AND a.userid = s.userid ");
+                                   AND $select a.userid = s.userid ");
     }
 }
 
@@ -440,32 +455,42 @@ function assignment_get_all_submissions($assignment, $sort="", $dir="DESC") {
     } else {
         $sort = "a.$sort $dir";
     }
+    
+    $select = "s.course = '$assignment->course' AND";
+    $site = get_site();
+    if ($assignment->course == $site->id) {
+        $select = '';
+    }
     return get_records_sql("SELECT a.* 
                               FROM {$CFG->prefix}assignment_submissions a, 
                                    {$CFG->prefix}user_students s,
                                    {$CFG->prefix}user u
                              WHERE a.userid = s.userid
                                AND u.id = a.userid
-                               AND s.course = '$assignment->course'
-                               AND a.assignment = '$assignment->id' 
+                               AND $select a.assignment = '$assignment->id' 
                           ORDER BY $sort");
 }
 
 function assignment_get_users_done($assignment) {
 /// Return list of users who have done an assignment
     global $CFG;
+    
+    $select = "s.course = '$assignment->course' AND";
+    $site = get_site();
+    if ($assignment->course == $site->id) {
+        $select = '';
+    }
     return get_records_sql("SELECT u.* 
                               FROM {$CFG->prefix}user u, 
                                    {$CFG->prefix}user_students s, 
                                    {$CFG->prefix}assignment_submissions a
-                             WHERE s.course = '$assignment->course' 
-                               AND s.userid = u.id
+                             WHERE $select s.userid = u.id
                                AND u.id = a.userid 
                                AND a.assignment = '$assignment->id'
                           ORDER BY a.timemodified DESC");
 }
 
-function assignment_get_unmailed_submissions($cutofftime) {
+function assignment_get_unmailed_submissions($starttime, $endtime) {
 /// Return list of marked submissions that have not been mailed out for currently enrolled students
     global $CFG;
     return get_records_sql("SELECT s.*, a.course, a.name
@@ -473,8 +498,8 @@ function assignment_get_unmailed_submissions($cutofftime) {
                                    {$CFG->prefix}assignment a,
                                    {$CFG->prefix}user_students us
                              WHERE s.mailed = 0 
-                               AND s.timemarked < $cutofftime 
-                               AND s.timemarked > 0
+                               AND s.timemarked <= $endtime 
+                               AND s.timemarked >= $starttime
                                AND s.assignment = a.id
                                AND s.userid = us.userid
                                AND a.course = us.course");
@@ -571,7 +596,7 @@ function assignment_print_submission($assignment, $user, $submission, $teachers,
     echo "</TABLE><BR CLEAR=ALL>\n";
 }
 
-function assignment_print_feedback($course, $submission) {
+function assignment_print_feedback($course, $submission, $assignment) {
     global $CFG, $THEME, $RATING;
 
     if (! $teacher = get_record("user", "id", $submission->teacher)) {
@@ -592,10 +617,12 @@ function assignment_print_feedback($course, $submission) {
     echo "\n<TR><TD WIDTH=100% BGCOLOR=\"$THEME->cellcontent\">";
 
     echo "<P ALIGN=RIGHT><FONT SIZE=-1><I>";
-    if ($submission->grade or $submission->timemarked) {
-        echo get_string("grade").": $submission->grade";
-    } else {
-        echo get_string("nograde");
+    if ($assignment->grade) {
+        if ($submission->grade or $submission->timemarked) {
+            echo get_string("grade").": $submission->grade";
+        } else {
+            echo get_string("nograde");
+        }
     }
     echo "</I></FONT></P>";
 
